@@ -20,85 +20,39 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-kinesisstreams-lambda`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.kinesisstreamslambda`|
 
-## Overview
-
 This AWS Solutions Construct deploys a Kinesis Stream and Lambda function with the appropriate resources/properties for interaction and security.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
-Typescript
-
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { KinesisStreamsToLambda } from '@aws-solutions-constructs/aws-kinesisstreams-lambda';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
+```javascript
+const { KinesisStreamsToLambda } from '@aws-solutions-constructs/aws-kinesisstreams-lambda';
 
 new KinesisStreamsToLambda(this, 'KinesisToLambdaPattern', {
-  kinesisEventSourceProps: {
-    startingPosition: lambda.StartingPosition.TRIM_HORIZON,
-    batchSize: 1
-  },
-  lambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_14_X,
-    handler: 'index.handler',
-    code: lambda.Code.fromAsset(`lambda`)
-  }
+    kinesisEventSourceProps: {
+        startingPosition: lambda.StartingPosition.TRIM_HORIZON,
+        batchSize: 1
+    },
+    lambdaFunctionProps: {
+        runtime: lambda.Runtime.NODEJS_10_X,
+        handler: 'index.handler',
+        code: lambda.Code.fromAsset(`${__dirname}/lambda`)
+    }
 });
-```
-
-Python
-
-```python
-from aws_solutions_constructs.aws_kinesis_streams_lambda import KinesisStreamsToLambda
-from aws_cdk import (
-    aws_lambda as _lambda,
-    aws_lambda_event_sources as sources,
-    aws_kinesis as kinesis,
-    Stack
-)
-from constructs import Construct
-
-KinesisStreamsToLambda(self, 'KinesisToLambdaPattern',
-                        kinesis_event_source_props=sources.KinesisEventSourceProps(
-                            starting_position=_lambda.StartingPosition.TRIM_HORIZON,
-                            batch_size=1
-                        ),
-                        lambda_function_props=_lambda.FunctionProps(
-                            runtime=_lambda.Runtime.PYTHON_3_9,
-                            handler='index.handler',
-                            code=_lambda.Code.from_asset(
-                                'lambda')
-                        )
-                        )
 
 ```
 
-Java
+## Initializer
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.eventsources.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.kinesisstreamslambda.*;
-
-new KinesisStreamsToLambda(this, "KinesisToLambdaPattern", new KinesisStreamsToLambdaProps.Builder()
-        .kinesisEventSourceProps(new KinesisEventSourceProps.Builder()
-                .startingPosition(StartingPosition.TRIM_HORIZON)
-                .batchSize(1)
-                .build())
-        .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_14_X)
-                .code(Code.fromAsset("lambda"))
-                .handler("index.handler")
-                .build())
-        .build());
+```text
+new KinesisStreamsToLambda(scope: Construct, id: string, props: KinesisStreamsToLambdaProps);
 ```
 
+*Parameters*
+
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`KinesisStreamsToLambdaProps`](#pattern-construct-props)
+
 ## Pattern Construct Props
 
 | **Name**     | **Type**        | **Description** |
@@ -146,7 +100,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -158,19 +112,17 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_kinesis
 import aws_cdk.aws_lambda
 import aws_cdk.aws_sqs
-import aws_cdk.core
+import constructs
 
 
 class KinesisStreamsToLambda(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-kinesisstreams-lambda.KinesisStreamsToLambda",
 ):
@@ -180,7 +132,7 @@ class KinesisStreamsToLambda(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
@@ -188,9 +140,9 @@ class KinesisStreamsToLambda(
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_event_source_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -208,10 +160,6 @@ class KinesisStreamsToLambda(
         :since: 0.8.0
         :summary: Constructs a new instance of the KinesisStreamsToLambda class.
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(KinesisStreamsToLambda.__init__)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KinesisStreamsToLambdaProps(
             create_cloud_watch_alarms=create_cloud_watch_alarms,
             deploy_sqs_dlq_queue=deploy_sqs_dlq_queue,
@@ -225,17 +173,17 @@ class KinesisStreamsToLambda(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
@@ -266,9 +214,9 @@ class KinesisStreamsToLambdaProps:
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_event_source_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         '''The properties for the KinesisStreamsToLambda class.
 
@@ -287,16 +235,6 @@ class KinesisStreamsToLambdaProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(sqs_dlq_queue_props, dict):
             sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
-        if __debug__:
-            type_hints = typing.get_type_hints(KinesisStreamsToLambdaProps.__init__)
-            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
-            check_type(argname="argument deploy_sqs_dlq_queue", value=deploy_sqs_dlq_queue, expected_type=type_hints["deploy_sqs_dlq_queue"])
-            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
-            check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
-            check_type(argname="argument kinesis_event_source_props", value=kinesis_event_source_props, expected_type=type_hints["kinesis_event_source_props"])
-            check_type(argname="argument kinesis_stream_props", value=kinesis_stream_props, expected_type=type_hints["kinesis_stream_props"])
-            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
-            check_type(argname="argument sqs_dlq_queue_props", value=sqs_dlq_queue_props, expected_type=type_hints["sqs_dlq_queue_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if create_cloud_watch_alarms is not None:
             self._values["create_cloud_watch_alarms"] = create_cloud_watch_alarms
